class FluKhomkrit:
	"""
	คลาส FluKhomkrit คือ ข้อมูลของนายคมตู่
	ประกอบด้วยชื่อเพจ
	ชื่อยูทูป

	Examle
	#-------------------------
	fluk = FluKhomkrit()
	fluk.show_name()
	fluk.show_youtube()
	fluk.adout()
	#-------------------------
	"""
	def __init__(self):
		self.name = 'คุณคมตู่'
		self.page = 'https://web.facebook.com/khomkit.fook'

	def show_name(self):
		print(f'สวัสดีฉันชื่อ {self.name}')

	def show_youtube(self):
		print('https://www.youtube.com/watch?v=O8YqI8IwFk4')

	def adout(self):
		text = """
		กกกกกกกกกกกกกกกกกกกกกกกกกกกกกกกกกกกกกกก
		ขขขขขขขขขขขขขข 'ฟลุ๊ค' ขขขขขขขขขขขขขขขข
		คคคคคคคคคคคคคคคคคคคคคคคคคคคคคคคคคคคคคคค
		งงงงงงงงงงงงงงงงงงงงงงงงงงงงงงงงงงงงงงงงงงงงงงงงงงงงงงงงง
		"""
		print(text)

if __name__ == '__main__':
	fluk = FluKhomkrit()
	fluk.show_name()
	fluk.show_youtube()
	fluk.adout()


import io
from os.path import abspath, dirname, join
from setuptools import find_packages, setup


HERE = dirname(abspath(__file__))
LOAD_TEXT = lambda name: io.open(join(HERE, name), encoding='UTF-8').read()
DESCRIPTION = '\n\n'.join(LOAD_TEXT(_) for _ in [
    'README.rst'
])

setup(
  name = 'myflukhomkrit',      
  packages = ['myflukhomkrit'], 
  version = '0.0.1', 
  license='MIT', 
  description = 'What is a khomkrit',
  long_description=DESCRIPTION,
  author = 'khomkrit',                 
  author_email = 'fookhomkrit@gmail.com',     
  url = 'https://github.com/flukhomkrit/BasicPython-1',  
  download_url = 'https://github.com/flukhomkrit/BasicPython-1',  
  keywords = ['flukhomkrit', 'khomkrit'],
  classifiers=[
    'Development Status :: 3 - Alpha',     
    'Intended Audience :: Education',     
    'Topic :: Utilities',
    'License :: OSI Approved :: MIT License',   
    'Programming Language :: Python :: 3',      
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
    'Programming Language :: Python :: 3.10',
  ],
)